summaryrefslogtreecommitdiffstats
path: root/src/H5E.c
diff options
context:
space:
mode:
authorDana Robinson <43805+derobins@users.noreply.github.com>2023-06-28 22:48:12 (GMT)
committerGitHub <noreply@github.com>2023-06-28 22:48:12 (GMT)
commitaebac33a1f290fa5065bce96bb0512317a34c283 (patch)
treecdbae6dbd65a2eb4e6f786921ee907cec92c92d3 /src/H5E.c
parent605cea4af60cfcbe03a54f697de392eec75e5a85 (diff)
downloadhdf5-aebac33a1f290fa5065bce96bb0512317a34c283.zip
hdf5-aebac33a1f290fa5065bce96bb0512317a34c283.tar.gz
hdf5-aebac33a1f290fa5065bce96bb0512317a34c283.tar.bz2
Remove HD from memory allocate/free calls (#3195)
* HDcalloc * HDfree * HDmalloc * HDrealloc
Diffstat (limited to 'src/H5E.c')
-rw-r--r--src/H5E.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5E.c b/src/H5E.c
index ca7da2c..1c82e5d 100644
--- a/src/H5E.c
+++ b/src/H5E.c
@@ -333,10 +333,10 @@ H5E__get_stack(void)
/* Win32 has to use LocalAlloc to match the LocalFree in DllMain */
estack = (H5E_t *)LocalAlloc(LPTR, sizeof(H5E_t));
#else
/* Use HDmalloc here since this has to match the HDfree in the
* destructor and we want to avoid the codestack there.
*/
- estack = (H5E_t *)HDmalloc(sizeof(H5E_t));
+ estack = (H5E_t *)malloc(sizeof(H5E_t));
#endif /* H5_HAVE_WIN_THREADS */
assert(estack);
@@ -1347,10 +1347,10 @@ done:
if (va_started)
va_end(ap);
/* Memory was allocated with HDvasprintf so it needs to be freed
- * with HDfree
+ * with free
*/
if (tmp)
- HDfree(tmp);
+ free(tmp);
FUNC_LEAVE_API(ret_value)
} /* end H5Epush2() */
@@ -333,10 +333,10 @@ H5E__get_stack(void)
estack = (H5E_t *)LocalAlloc(LPTR, sizeof(H5E_t));
#else
- /* Use HDmalloc here since this has to match the HDfree in the
+ /* Use malloc here since this has to match the free in the
* destructor and we want to avoid the codestack there.
*/